Struct rustc_mir::transform::MirSource
[−]
[src]
pub struct MirSource {
pub def_id: DefId,
pub promoted: Option<Promoted>,
}🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Where a specific Mir comes from.
Fields
def_id: DefId
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
promoted: Option<Promoted>
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
If Some, this is a promoted rvalue within the parent function.
Methods
impl MirSource[src]
pub fn item(def_id: DefId) -> Self[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?